@@ -1,5 +1,7 @@
 from typing import Union, List
 
+import pexpect
+
 from figcli.utils.utils import Utils
 import sys
 
@@ -10,24 +12,32 @@ class FiggyAction:
     of tests.
     """
 
-    def __init__(self, child, extra_args=""):
+    def __init__(self, command, extra_args=""):
         self.c = Utils.default_colors()
+        self.command = command
         self.extra_args = extra_args
+        self._child = self.spawn(command)
+        print(f"{self.c.fg_yl}Executing action: {self._child.args}{self.c.rs}")
+        self._child.logfile = sys.stdout
+        self._child.delaybeforesend = .5
 
-        if child:
-            c = Utils.default_colors()
-            print(f"{c.fg_yl}Executing action: {child.args}{c.rs}")
-            self._child = child
-            self._child.logfile = sys.stdout
-            self._child.delaybeforesend = .5
+    def spawn(self, command: str):
+        return pexpect.spawn(command, timeout=10, encoding='utf-8')
 
     def expect_multiple(self, regexes: List[str]):
         print(f'Expecting: {regexes}')
         return self._child.expect(regexes)
 
-    def expect(self, regex: Union[List[str], str]):
+    def expect(self, regex: Union[List[str], str], retry=True):
         print(f'Expecting: {regex}')
-        return self._child.expect(regex)
+        expect_list = [regex] + [pexpect.TIMEOUT] if isinstance(regex, str) else regex + [pexpect.TIMEOUT]
+        result = self._child.expect(expect_list)
+        if result == len(expect_list) - 1 and retry:
+            self.alert(f"EXPECT FAILED: {regex} initiating retry!")
+            self._child = self.spawn(self.command)
+            return self.expect(regex, retry=False)
+        else:
+            return result
 
     def sendline(self, line: str):
         print(f'Sending: {line}')
