@@ -23,6 +23,11 @@ class FiggyTest(ABC):
     def run(self):
         pass
 
+    def log(self, text: str):
+        with open('/tmp/figgy.log', "a+") as l:
+            l.writelines([text])
+
+
     def expect_multiple(self, regexes: List[str]):
         print(f'Expecting: {regexes}')
         return self._child.expect(regexes)
@@ -42,4 +47,17 @@ class FiggyTest(ABC):
 
     def wait(self):
         print("Waiting for child process to exit...")
-        self._child.wait()
\ No newline at end of file
+        self._child.wait()
+
+    def readline(self, count=1, child=None):
+        data = ""
+        for i in range(0, count):
+            if child:
+                data += child.readline()
+            else:
+                data += self.readline()
+
+        return data
+
+    def sendcontrol(self, characters: str):
+        return self._child.sendcontrol(characters)
\ No newline at end of file
